## TVM - TV Manager

[![Build Status](https://travis-ci.org/davidvuong/tvm.svg?branch=master)](https://travis-ci.org/davidvuong/tvm)

TVM is a command line tool that helps you manage your TV shows. It's currently in early development and will be available via pypi when v0.1 is released.

## Usage

```
tvm.py

usage:
    tvm.py add <path> [--append]
    tvm.py doctor [--exists]
    tvm.py play (<title>... [--no-open --info --random]|(--undo|--random))
    tvm.py info [<title>... [--more]]
    tvm.py ls
    tvm.py check [--download] [--sleep=<n>] [--without-cache] [--untracked]

commands:
    add              generates records to be added in shows_added with <path>.
    play             plays the next episode in the given tv show <title>.
    doctor           checks for syntax and semantic errors in the recored files.
    info             shows basic information about the given tv show <title>.
    ls               lists all tv shows recorded.
    check            checks for new tv shows to download.

add:
    --append         appends stdout to records.

doctor:
    --exists         checks if physical files exists in the records.

play:
    --no-open        records but doesn't open the episode.
    --info           shows basic statistical information.
    --random         randomly selects a show to play.
    --undo           undos the most previously played episode.

info:
    --more           shows additional information from online sources.

check:
    --download       downloads all queued shows as well as checks for new updates.
    --sleep=<n>      sleeps n seconds before performing the check [default: 0].
    --without-cache  checks but does not store results in cache.
    --untracked      shows untracked episodes that can be downloaded.

arguments:
    <path>           directory containing tv shows.
    <title>          title of the tv show.

options:
    -h --help        shows this.
    -v --version     shows version.

>>
```

## Getting Started

*comming soon...*

## Developer

1. First, download and setup a virtual environment.

        git clone git@github.com:davidvuong/tvm.git
        mkvirtualenv tvm
        cd tvm

2. Next, you need to install the package dependencies.

        pip install -r requirements.txt
        python setup.py develop

3. If you're having issues compiling, due to this error (Mac specific):

        clang: error: unknown argument: '-mno-fused-madd' [-Wunused-command-line-argument-hard-error-in-future]
        clang: note: this will be a hard error (cannot be downgraded to a warning) in the future
        error: command 'cc' failed with exit status 1

4. You can temporarily fix it by performing the following export:

        export ARCHFLAGS="-Wno-error=unused-command-line-argument-hard-error-in-future"

5. Once everything has successfully install, you can test and run tvm to see if it works.

        fab test
        tvm -h

    If tests pass and no errors pop up, you're all good to go.

## Future

* `doctor` command should also check for missing episodes. May of forgotten to download an episode.
* Add `--force` option to the `play` command to open the next available episode when episodes are missing.
* An additional file that stores each tv show's, most recently updated, last viewed etc. stats and adding a `--cache` option so commands can run faster.
* Implement the `ls` command from tv-manager.py
* Add a new filter, `filter=new` to the `ls` command.
* ls `<title>...` should directly display show specific episodes as a tree.
* Add a `new` command that looks at records to see if I'm updated with a tv show.
* Add a `--queue=<n>` param on play command to queue n number of next episodes.
* Properly calculate episode count as some have multiple episodes in a single title.
* `tvm play` without arguments should look at the last previously played episode and play the next episde.
* Adding commit hooks to check for code style against pep8.
* Recompile Terminal-Notifier to use a new icon and set the NC title to "TVM".
* `add` command ignore shows that have already been added when `<path>` points to a directory with pre-existing files. In addition, a `--force` option would be good to override that behaviour.
* After adding entries to the records, it might be useful to show the tail of the updated `show_added` record.
* `doctor` should have a `--fix` option that resolves errors found.
* configuration file should have a `ignore_errors` key to stop showing load errors every time a command is ran when records are mismatched.
* `doctor` should check for updates on github.
