#!/usr/bin/env python
# -*- coding: utf-8 -*-
from time import sleep

from tvm.commands import basecommand
from tvm.shared_helpers.io import err, warn, info, ok
from tvm.shared_helpers.sources.rss import RSSSource, create_rss

from tvm.helpers.checkhelper import CheckHelper


class CheckCommand(basecommand.BaseCommand):
    def __init__(self, **arguments):
        super(self.__class__, self).__init__(**dict(arguments, **{'_ignore_errors': True}))

        self.helper = CheckHelper(self.config, self.collection)
        self._extact_args(arguments)
        self._exec()

    def _extact_args(self, arguments):
        self._download = arguments.get('--download', False)
        self._without_cache = arguments.get('--without-cache', False)
        self._untracked = arguments.get('--untracked', False)
        try:
            self._sleepn = int(arguments.get('--sleep', 0))
            if self._sleepn < 0:
                err('--sleep=<n> must be a positive integer.')
                exit(0)

        except ValueError:
            err('--sleep=<n>, "%s" is not a number.' % arguments['--sleep'])
            exit(0)

    def _exec(self):
        if self._sleepn:
            info('Sleeping %d second(s) before executing check command.' % self._sleepn)
            sleep(self._sleepn)

        rss = RSSSource(self.config, self.collection)
        if not self._without_cache:
            self.helper.store_to_cache(rss)

        if self._download:
            self.helper.download_shows()

        # Create a RSSSource using queued downloads from the cache directory.
        combined_rss = create_rss(self.helper.load_from_cache(), self.config, self.collection)
        self.helper.notify(combined_rss)
        self.helper.print_updates(combined_rss, show_untracked=self._untracked)
