#!/usr/bin/env python
# -*- coding: utf-8 -*-
from tvm.commands import basecommand
from tvm.shared_helpers.io import err, warn, info, info2, ok
from tvm.shared_helpers.io import print_matched_status
from tvm.helpers.playhelper import PlayHelper


class PlayCommand(basecommand.BaseCommand):
    def __init__(self, **arguments):
        super(self.__class__, self).__init__(**dict(arguments, **{'_ignore_errors': True}))

        self.helper = PlayHelper(self.config, self.collection)
        self._extact_args(arguments)
        self._exec()

    def _extact_args(self, arguments):
        # Join by '_' and not ' ' because internally, words are '_' delimited.
        self._search_query = '_'.join(arguments.get('<title>', []))
        self._no_open = arguments.get('--no-open', False)
        self._undo = arguments.get('--undo', False)
        self._info = arguments.get('--info', False)
        self._random = arguments.get('--random', False)

    def _exec(self):
        if self._undo:
            removed_episode = self.helper.undo_last_played()
            if not removed_episode:
                return err("Couldn't open shows_viewed.csv to remove most recently viewed.")
            return ok("'%s' --undo was successful." % removed_episode)

        matched = None
        if self._search_query:
            matched = self.collection.find_matching_titles(self._search_query)
            print_matched_status(matched)

        if self._random:
            return self.helper.simulate_random_selection(matched)

        next_to_watch = self.helper.next_to_watch(matched)
        if not next_to_watch:
            info('No new episodes for "%s".' % matched)
        else:
            if self._no_open:
                info('Not opening the TV show "%s".' % ','.join(next_to_watch))
                self.helper.update_records_with(next_to_watch)

            info('Opening the episode, "%s".' % ','.join(next_to_watch))
            if not self.helper.play_episode(next_to_watch):
                err('Cannot open episode, "%s".' % ','.join(next_to_watch))
                info2('Try the --no-open option to record and not play the episode.')

        if self._info:
            self.helper.print_play_statistics(matched)
