#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import time

from datetime import datetime

from tvm.helpers import basehelper
from tvm.shared_helpers.io import err, warn, info, ok


class AddHelper(basehelper.BaseHelper):
    def __init__(self, config, collection):
        super(self.__class__, self).__init__(config, collection)

    def _created_datetime(self, path):
        mask = '%a %b %d %H:%M:%S %Y'
        return datetime.strptime(time.ctime(os.path.getmtime(path)), mask)

    def _build_csv_records(self, stored_files):
        stored_files = sorted(stored_files, key=lambda x: x[0])
        return '\n'.join(map(lambda row: '%s,%s,%s,%s' % row, stored_files))

    def load_stored_files(self, path):
        if not os.path.exists(path) or not os.path.isdir(path):
            err('<path> must be an existing directory.')
            exit(0)

        stored_files = []
        for dirname, _, filenames in os.walk(path):
            for filename in filenames:
                if filename.startswith('.'):
                    continue

                path = os.path.join(dirname, filename)
                episode, ext = os.path.splitext(filename)
                title, season = os.path.split(dirname)

                # The title might be like x/y/title so we need to fix that.
                title = '"' + os.path.basename(title) + '"'

                created_datetime = self._created_datetime(path)
                stored_files.append((created_datetime, season, episode, title))

        return self._build_csv_records(stored_files)
