#!/usr/bin/env python
# -*- coding: utf-8 -*-
from tvm.helpers import basehelper

from tvm.shared_helpers.tvstatistics import TVStatistics
from tvm.shared_helpers.datehelpers import pretty_date

from tvm.shared_helpers.io import print_errors
from tvm.shared_helpers.io import err, warn, info, info2, ok

from tvm.shared_helpers.sources.data import DataSource


class InfoHelper(basehelper.BaseHelper):
    def __init__(self, config, collection):
        super(self.__class__, self).__init__(config, collection)

        self._statistics = TVStatistics(self.collection)

    def _print_statistics(self, statistics, **kwargs):
        view_percentage = kwargs.get('view_percentage', 0)
        viewed_episodes = kwargs.get('viewed_episodes', [])
        all_episodes = kwargs.get('all_episodes', [0])

        info2('%.2f%% (%d/%d) total views.' % (view_percentage, len(viewed_episodes), len(all_episodes)))
        for title in sorted(statistics.keys()):
            data = statistics[title]
            if not data or None in data:
                info2(title + ': Never');
            else:
                date, episode = data
                info2(title + ': %s, "%s"' % (pretty_date(date), ','.join(episode)))

    def gather_and_print_show_statistics(self, title=None, more=None):
        # TODO: Also fetch from themoviedb for show specific queries.
        #           - youtube link to trailer, tmdb-id, genre, date first released, title (alternate title)
        statistics, source = {
            'first_viewed': self._statistics.first_viewed_episode(title),
            'first_recorded': self._statistics.first_recorded_episode(title),
            'last_viewed': self._statistics.last_viewed_episode(title),
            'last_updated': self._statistics.last_updated_episode(title),
        }, None

        if title:
            info('Displaying info statistics: "%s"' % title)
            all_episodes, viewed_episodes = self.collection.find_all_episodes(title)
        else:
            info('Displaying non-specific info statistics:')
            all_episodes, viewed_episodes = self.collection.entries, self.collection.all_viewed_episodes

        self._print_statistics(statistics, **{
            'view_percentage': round(float(len(viewed_episodes)) / len(all_episodes), 2) * 100,
            'viewed_episodes': viewed_episodes,
            'all_episodes': all_episodes
        })

        if more and title:
            info('Gathering online data from themoviedb.')
            source = DataSource(self.config, title)
            if not source.matched:
                return info2('No additional data was found...')

            info2('in_production? %s' % source.in_production)
            info2('first_aired: %s' % pretty_date(source.first_aired))
            info2('last_aired: %s' % pretty_date(source.last_aired))
            info2('genres: %s ' % ', '.join(source.genres))
