#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import print_function
import string

from tvm.shared_helpers.tvstatistics import TVStatistics
from tvm.shared_helpers.datehelpers import pretty_date
from tvm.shared_helpers.io import info

from tvm.helpers import basehelper


class LsHelper(basehelper.BaseHelper):
    def __init__(self, config, collection):
        super(self.__class__, self).__init__(config, collection)

        self._statistics = TVStatistics(self.collection)

    def _calculate_max_column_width(self, table):
        column_widths = [0] * len(table[0])
        for i, column in enumerate(zip(*table)):
            for row in column:
                cell = str(row[1] if isinstance(row, (list, tuple)) else row)
                if len(cell) > column_widths[i]:
                    column_widths[i] = len(cell)
        return column_widths

    def _add_column_padding(self, table, padding=5):
        def _add_padding(column, i):
            return str(column) + ' ' * (column_widths[i] + padding - len(column))

        column_widths, new_table = self._calculate_max_column_width(table), []
        for row in table:
            new_row = []
            for i, column in enumerate(row):
                # Adjust center on all columns except first and last.
                adjust = string.center if i not in [0, len(row) - 1] else string.ljust
                new_row.append(adjust(str(column), column_widths[i] + padding))

            new_table.append(new_row)
        return new_table

    def generate_table(self):
        table = [['title', 'last_updated', 'last_viewed', 'seen_latest?']]
        for title in sorted(self.collection.titles):
            statistics = self._statistics._gather_date_statistics(title)
            table.append([
                title,
                pretty_date(statistics['last_updated'][0]),
                pretty_date(statistics['last_viewed'][0]),
                "\033[1;31mNO\033[0m" if self.collection.viewed_up_to_date(title) else "\033[0;32mYES\033[0m"
            ])

        return table

    def print_table(self, table):
        """ The columns of the first row in `table` are always the headings. """
        table = self._add_column_padding(table)

        info(''.join(table[0]))
        print('   ' + '-' * sum(map(len, table[0])))
        for i, row in enumerate(table[1:]):
            print('   ' + ''.join(map(str, row)))
