#!/usr/bin/env python
# -*- coding: utf-8 -*-
from datetime import datetime


def today_as_str():
    return datetime.now().strftime("%Y-%m-%d %H:%M:%S")


def convert_date(date):
    return None if not date else datetime.strptime(date, '%Y-%m-%d %H:%M:%S')


def convert_date_to_datetime(date):
    if date:
        return datetime.combine(date, datetime.min.time())


def pretty_date(time):
    if not time:
        return '-'

    if isinstance(time, str):
        return time

    now = datetime.now()
    diff = now - time

    second_diff = diff.seconds
    day_diff = diff.days

    if day_diff < 0:
        return ''

    if day_diff == 0:
        if second_diff < 10:
            return "just now"
        if second_diff < 60:
            return str(second_diff) + " seconds ago"
        if second_diff < 120:
            return "a minute ago"
        if second_diff < 3600:
            return str(round(second_diff / 60.0, 2)) + " minutes ago"
        if second_diff < 7200:
            return "an hour ago"
        if second_diff < 86400:
            return str(round(second_diff / 3600.0, 2)) + " hours ago"

    AM_PM = time.strftime("%I:%M %p").lstrip('0')
    if day_diff == 1:
        return "Yesterday at " + AM_PM
    if day_diff < 7:
        return str(day_diff) + " days ago (" + AM_PM + ")"
    if day_diff < 31:
        return str(round(day_diff / 7.0, 2)) + " weeks ago"
    if day_diff < 365:
        return str(round(day_diff / 30.0, 2)) + " months ago"

    return str(round(day_diff / 365.0, 2)) + " years ago"
