#!/usr/bin/env python
# -*- coding: utf-8 -*-
from collections import defaultdict


class TVStatistics(object):
    def __init__(self, collection):
        self.collection = collection

    def _gather_date_statistics(self, title=None):
        """ Provide a title to find date statistics on a specific show. """
        keys = [
            'last_updated',
            'first_recorded',
            'last_viewed',
            'first_viewed'
        ]

        # NOTE: Replace with change if we ever drop 2.6
        #       d = {key: value for (key, value) in sequence}
        date_statistics = dict((k, (None, None)) for k in keys)

        for episode, dates in self.collection.entries.iteritems():
            if title not in episode and title is not None:
                continue

            # dates = [[dates_viewed, ...], date_recorded]
            dates_viewed, date_recorded = dates

            # May contain None so we must prune those first -- sorts in ASC.
            dates_viewed = sorted([d for d in dates_viewed if d])

            if not date_statistics['last_updated'][0]:
                date_statistics['last_updated'] = (date_recorded, episode)
            if not date_statistics['first_recorded'][0]:
                date_statistics['first_recorded'] = (date_recorded, episode)
            if not date_statistics['last_viewed'][0] and dates_viewed:
                date_statistics['last_viewed'] = (dates_viewed[-1], episode)
            if not date_statistics['first_viewed'][0] and dates_viewed:
                date_statistics['first_viewed'] = (dates_viewed[0], episode)

            # Real comparisons where we actually have dates stored.
            if date_recorded >= date_statistics['last_updated'][0]:
                date_statistics['last_updated'] = (date_recorded, episode)
            if date_recorded <= date_statistics['first_recorded'][0]:
                date_statistics['first_recorded'] = (date_recorded, episode)

            # Not viewed... let's move on.
            if not dates_viewed:
                continue

            if dates_viewed[-1] >= date_statistics['last_viewed'][0]:
                date_statistics['last_viewed'] = (dates_viewed[-1], episode)
            if dates_viewed[0] <= date_statistics['first_viewed'][0]:
                date_statistics['first_viewed'] = (dates_viewed[0], episode)

        return date_statistics

    def first_viewed_episode(self, title=None):
        return self._gather_date_statistics(title)['first_viewed']

    def first_recorded_episode(self, title=None):
        return self._gather_date_statistics(title)['first_recorded']

    def last_viewed_episode(self, title=None):
        return self._gather_date_statistics(title)['last_viewed']

    def last_updated_episode(self, title=None):
        return self._gather_date_statistics(title)['last_updated']

    def most_viewed_episode(self, title=None):
        try:
            most_viewed = max(self.collection.entries, key=lambda k: len(self.collection.entries[k][0]))
            return (most_viewed, len(self.collection.entries[most_viewed][0]))
        except ValueError:
            return None

    def most_viewed_show(self):
        """ A very simple statistic that just looks at the total number of views per show. """
        most_viewed = defaultdict(int)
        for viewed, dates in self.collection.entries.iteritems():
            views, _ = dates
            _, _, title = viewed
            most_viewed[title] += len(views)

        most_viewed_title = max(most_viewed, key=most_viewed.get)
        return (most_viewed_title, most_viewed[most_viewed_title])
