#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""tvm.py

usage:
    tvm.py add <path> [--append]
    tvm.py doctor [--exists]
    tvm.py play (<title>... [--no-open --info --random]|(--undo|--random))
    tvm.py info [<title>... [--more]]
    tvm.py ls
    tvm.py check [--download] [--sleep=<n>] [--without-cache] [--untracked]

commands:
    add              generates records to be added in shows_added with <path>.
    play             plays the next episode in the given tv show <title>.
    doctor           checks for syntax and semantic errors in the recored files.
    info             shows basic information about the given tv show <title>.
    ls               lists all tv shows recorded.
    check            checks for new tv shows to download.

add:
    --append         appends stdout to records.

doctor:
    --exists         checks if physical files exists in the records.

play:
    --no-open        records but doesn't open the episode.
    --info           shows basic statistical information.
    --random         randomly selects a show to play.
    --undo           undos the most previously played episode.

info:
    --more           shows additional information from online sources.

check:
    --download       downloads all queued shows as well as checks for new updates.
    --sleep=<n>      sleeps n seconds before performing the check [default: 0].
    --without-cache  checks but does not store results in cache.
    --untracked      shows untracked episodes that can be downloaded.

arguments:
    <path>           directory containing tv shows.
    <title>          title of the tv show.

options:
    -h --help        shows this.
    -v --version     shows version.
"""
from __future__ import print_function

from docopt import docopt

import os
from inspect import getmembers, isclass

try:
    from shared_helpers import io
    from commands import *
except ImportError:
    import traceback
    traceback.print_exc()

    print('Development mode: Run with -m `python -m tvm/tvm [command] [arguments]`.')
    exit(0)


def main():
    __version__ = '0.1.0'
    arguments = docopt(__doc__, version=__version__)

    # Set the current directory to the directory of this file.
    os.chdir(os.path.dirname(os.path.abspath(__file__)))

    # Dynamically load corresponding command class given command name.
    for command, value in arguments.iteritems():
        if command.startswith('--'):  # Options.
            continue

        if command.startswith('<'):  # Positional arguments.
            continue

        if not value:  # Not a command that was called.
            continue

        _, klass = getmembers(globals()[command], isclass)[0]
        klass(**arguments)

if __name__ == '__main__':
    main()
